@@ -1,5 +1,5 @@
 
-module Graphics.Gloss.Rendering 
+module Graphics.Gloss.Rendering
         ( -- * Picture data type
           Picture (..)
         , Point, Vector, Path
@@ -14,11 +14,15 @@ module Graphics.Gloss.Rendering
         , clampColor
 
           -- * Bitmaps
-        , BitmapData
+        , Rectangle(..)
+        , BitmapData, bitmapSize
         , BitmapFormat(..), PixelFormat(..), RowOrder(..)
         , bitmapOfForeignPtr
+        , bitmapDataOfForeignPtr
         , bitmapOfByteString
+        , bitmapDataOfByteString
         , bitmapOfBMP
+        , bitmapDataOfBMP
         , loadBMP
 
           -- * Rendering
@@ -38,11 +42,11 @@ import qualified Graphics.Gloss.Internals.Rendering.State as RS
 
 
 -- | Set up the OpenGL context, clear the buffer, and render the given picture
---   into it. 
+--   into it.
 --
 --   This is the same as `renderPicture` composed with `withModelview`
 --   and `withClearBuffer`. If you want to manage your own OpenGL context then
---   you can just call `renderPicture`. 
+--   you can just call `renderPicture`.
 --
 --   Using this function assumes that you've already opened a window
 --   and set that to the active context. If you don't want to do your own window
@@ -60,3 +64,4 @@ displayPicture windowSize colorClear state scale picture
   = withModelview      windowSize
   $ withClearBuffer    colorClear
   $ renderPicture  state scale picture
+
